@@ -18,3 +18,12 @@ impl Display for StringLiteral<'_> {
     )
   }
 }
+
+impl<'src> Serialize for StringLiteral<'src> {
+  fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
+  where
+    S: Serializer,
+  {
+    serializer.serialize_str(&self.cooked)
+  }
+}
