@@ -1,7 +1,4 @@
-use std::{fs, process::Command};
-
-use executable_path::executable_path;
-use test_utilities::assert_success;
+use crate::common::*;
 
 #[test]
 fn examples() {
